Module client

Module client 

Minimal Redis client implementation

Provides an async connect and methods for issuing the supported commands.

Structs

Client
Established connection with a Redis server.
Message
A message received on a subscribed channel.
Subscriber
A client that has entered pub/sub mode.

Functions

connect
Establish a connection with the Redis server located at addr.