[−][src]Enum mini_redis::cmd::Command
Enumeration of supported Redis commands.
Methods called on Command are delegated to the command implementation.
Variants
Get(Get)Publish(Publish)Set(Set)Subscribe(Subscribe)Unsubscribe(Unsubscribe)Unknown(Unknown)Implementations
impl Command[src]
pub fn from_frame(frame: Frame) -> Result<Command>[src]
Parse a command from a received frame.
The Frame must represent a Redis command supported by mini-redis and
be the array variant.
Returns
On success, the command value is returned, otherwise, Err is returned.