[−][src]Struct mini_redis::cmd::Set
Set key to hold the string value.
If key already holds a value, it is overwritten, regardless of its type.
Any previous time to live associated with the key is discarded on successful
SET operation.
Options
Currently, the following options are supported:
- EX
seconds-- Set the specified expire time, in seconds. - PX
milliseconds-- Set the specified expire time, in milliseconds.
Implementations
impl Set[src]
pub fn new(key: impl ToString, value: Bytes, expire: Option<Duration>) -> Set[src]
Create a new Set command which sets key to value.
If expire is Some, the value should expire after the specified
duration.
pub fn key(&self) -> &str[src]
Get the key
pub fn value(&self) -> &Bytes[src]
Get the value
pub fn expire(&self) -> Option<Duration>[src]
Get the expire